# mediainline-PyPi-packages

<!-- descripsion -->
This repository contains the source code and documentation for the Inception Renderer Python package, which is available on PyPi. The Inception Renderer is a powerful tool for rendering any youtube videos and any web page over the Jupyter/Colab Notebook.

# How to run?
## Installation:

#### Create a conda environment

```bash
conda create -n render python=3.8 -y
```

```bash
conda activate render
```


```bash
pip install -r requirements_dev.txt
```